@@ -5,7 +5,6 @@ namespace onespace\tools\enum\oneaccess;
 use onespace\tools\enum\base\UnbackedHelper;
 
 enum ReaderType {
-
     use UnbackedHelper;
 
     case BLUETOOTH;
@@ -19,20 +18,17 @@ enum ReaderType {
             ],
             self::OSDP => [
                 'id' => 2,
-                'name' => 'OSDP'
+                'name' => 'OSDP',
             ],
         };
         return $config[$key];
     }
 
-
     public function id(): int {
         return $this->config('id');
     }
 
-
     public function name(): string {
         return $this->config('name');
     }
-
 }
